@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Last-in, First-out array
 
-our $VERSION = '0.0101';
+our $VERSION = '0.02';
 
 use Moose;
 use namespace::autoclean;
@@ -73,6 +73,12 @@ around add => sub {
     $last;
 };
 
+sub peek {
+    my $self = shift;
+    my $element = shift || 0;
+    return $self->queue->[$element];
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -89,7 +95,7 @@ Array::LIFO - Last-in, First-out array
 
 =head1 VERSION
 
-version 0.0101
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -101,6 +107,7 @@ version 0.0101
   print $ar->size, "\n";
   print $ar->average, "\n";
   print $ar->sum, "\n";
+  print $ar->peek, "\n";
   $ar->remove;
   print "@{ $ar->queue }\n";
 
@@ -115,7 +122,7 @@ Array::LIFO - Last-in, First-out array
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
   $x = Array::LIFO->new;
   $x = Array::LIFO->new( max_size => $m );
@@ -146,28 +153,40 @@ Remove the last item on the array.
 
 =head2 size
 
-    $ar->size;
+    $size = $ar->size;
 
 How many elements are in the array.
 
 =head2 max_size
 
-    $ar->max_size;
+    $max = $ar->max_size;
 
 The maximum size the array is allow to be.
 
 =head2 sum
 
-    $ar->sum;
+    $sum = $ar->sum;
 
 The sum of all numeric elements in the array.
 
-=head2 C<average>
+=head2 average
 
-    $ar->average;
+    $avg = $ar->average;
 
 The average of all numeric elements in the array.
 
+=head2 peek
+
+    $last = $ar->peek;
+    $element = $ar->peek($index);
+
+Return an element of the array given by the index argument.  If no index is
+provided, the last element added to the stack is returned.
+
+=head1 SEE ALSO
+
+L<Array::FIFO>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
